# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  boot.initrd.luks.devices."luks-1cd83c7a-abab-419f-8e7b-c907f234a00f".device = "/dev/disk/by-uuid/1cd83c7a-abab-419f-8e7b-c907f234a00f";
  networking.hostName = "lena"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Enable networking
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/Berlin";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "de_DE.UTF-8";
    LC_IDENTIFICATION = "de_DE.UTF-8";
    LC_MEASUREMENT = "de_DE.UTF-8";
    LC_MONETARY = "de_DE.UTF-8";
    LC_NAME = "de_DE.UTF-8";
    LC_NUMERIC = "de_DE.UTF-8";
    LC_PAPER = "de_DE.UTF-8";
    LC_TELEPHONE = "de_DE.UTF-8";
    LC_TIME = "de_DE.UTF-8";
  };

  # Configure keymap in X11
  services.xserver.enable = true;
  services.xserver = {
    layout = "de";
    xkbVariant = "";
  };

  # Configure console keymap
  console.keyMap = "de";

  # Enabling xbindkeys service for special media keys
  systemd.user.services.xbindkeys.enable = true;

  # Enabling Audio
  sound.enable = true;
  hardware.pulseaudio.enable = true;
  hardware.pulseaudio.support32Bit = true;
  hardware.pulseaudio.package = pkgs.pulseaudioFull;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.forestcat = {
    isNormalUser = true;
    description = "forestcat";
    extraGroups = ["networkmanager" "wheel" "audio"];
    packages = with pkgs; [];
  };
  users.defaultUserShell = pkgs.nushell;

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    # System Packages go here
    pkgs.brave
    pkgs.scrot
    pkgs.imagemagick
    pkgs.papirus-nord
    pkgs.papirus-icon-theme
    pkgs.signal-desktop
    pkgs.tree
    pkgs.rofi
    pkgs.i3blocks
    pkgs.i3
    pkgs.prismlauncher
    pkgs.alejandra
    pkgs.keepassxc
    pkgs.kitty
    pkgs.swww
    pkgs.rofi-wayland
    pkgs.waybar
    # pkgs.dunst
    pkgs.firefox
    pkgs.keepassxc
    pkgs.lf
    pkgs.networkmanagerapplet
    pkgs.discord
    pkgs.element-desktop
    pkgs.wget
    pkgs.helix
    pkgs.unzip
    pkgs.tldr
    pkgs.steam
    pkgs.git
    pkgs.awesome
    pkgs.lightdm
    pkgs.neofetch
    pkgs.pulseaudioFull
    pkgs.toybox
    pkgs.pavucontrol
    pkgs.lxappearance
    pkgs.lxappearance-gtk2
    pkgs.xorg.xev
    pkgs.xfce.xfce4-pulseaudio-plugin
    pkgs.xbindkeys
    pkgs.xbindkeys-config
    pkgs.traceroute
    pkgs.xorg.xinit
    pkgs.nil
  ];

  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };

  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  # services.openssh.enable = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.05"; # Did you read the comment?

  # Enabling wayland
  # programs.sway.enable = true;
  xdg.portal.enable = true;
  xdg.portal.extraPortals = [pkgs.xdg-desktop-portal-gtk];
  # services.xserver.wayland.enable = true;

  # Enabling awesome WM
  # services.xserver.windowManager.awesome.enable = true;
  services.xserver.desktopManager.xfce.enable = true;
  services.xserver.windowManager.i3.enable = true;
  # services.xserver.windowManager.i3.configFile = "./local-configs/config";
  # Enable Flatpack support
  services.flatpak.enable = true;

  # Enabling LightDM
  services.xserver.displayManager.lightdm.enable = true;

  # Hyperland
  # programs.hyprland = {
  # enable = true;
  # xwayland.enable = true;
  # };

  environment.sessionVariables = {
    WLR_NO_HARDWARE_CURSORS = "1"; # if mouse cursor invisible
    NIXOS_OZONE_WL = "1"; # hint electron apps to use wayland
  };

  hardware = {
    opengl.enable = true; # Enable opengl
    nvidia.modesetting.enable = true;
  };

  # Enabling Pipewire for Audio Support
  services.pipewire.enable = true;
  nix.settings.experimental-features = ["nix-command" "flakes"];
  services.printing.enable = true;

  services.avahi = {
    enable = true;
    nssmdns = true;
    openFirewall = true;
  };
  # Automatic Garbage collection
  nix.gc = {
    automatic = true;
    dates = "weekly";
    options = "--delete-older-than 7d";
  };
  #Hardwarebeschleunigung f@r wayland
  # hardware.opengl = {
  # enable = true;
  # driSupport = true;
  # extraPackages = with pkgs; [ libva libva-utils libva-intel-driver ];
  # };
}
